@@ -2,7 +2,7 @@ from .base import BaseDeployment
 from .commands import (init, add_deployment, set_deployment)
 
 from .api import virtualenv
-from .decorators import ensure_use_deployment
+from .decorators import ensure_use_deployment, easyfabtask
 from .errors import MissingDeploymentError
 from .utils import is_easyfab_task, process_directory
 
